# MLbull

How to run with makefile:

first install poetry

then run
```
make install
```
to install all dependencies

then run
```
make dev
```
to run the server

if the make dave fails because of a missing package, run
```
make update-deps
```
to install the missing package

